<?php
/**
 * bold functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Bold
 */

if ( ! function_exists( 'bold_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function bold_setup() {
  /*
   * Make theme available for translation.
   * Translations can be filed in the /languages/ directory.
   * If you're building a theme based on Real, use a find and replace
   * to change 'bold' to the name of your theme in all the template files.
   */
  load_theme_textdomain( 'bold', get_template_directory() . '/languages' );

  // Add default posts and comments RSS feed links to head.
  add_theme_support( 'automatic-feed-links' );

  /*
   * Add Custom Header Support
   */
  $args = array(
    'flex-width'    => true,
    'flex-height'   => true,
    'default-image' => '',
  );

  add_theme_support( 'custom-header', $args );

  /*
   * Add Custom Logo Support
   */
  add_theme_support('custom-logo', array(
    'height'     => 32,
    'width'      => 150,
    'flex-width' => true,
    'flex-height' => true,
  ));

  /*
   * Let WordPress manage the document title.
   * By adding theme support, we declare that this theme does not use a
   * hard-coded <title> tag in the document head, and expect WordPress to
   * provide it for us.
   */
  add_theme_support( 'title-tag' );

  /*
   * Enable support for Post Thumbnails on posts and pages.
   *
   * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
   */
  add_theme_support( 'post-thumbnails' );

  // This theme uses wp_nav_menu() in one location.
  register_nav_menus( array(
    'primary' => esc_html__( 'Primary Menu', 'bold' ),
    'social'  => esc_html__( 'Social Menu', 'bold' )
  ) );

  /*
   * Switch default core markup for search form, comment form, and comments
   * to output valid HTML5.
   */
  add_theme_support( 'html5', array(
    'search-form',
    'comment-form',
    'comment-list',
    'gallery',
    'caption',
  ) );

  /**
   * Return entry full featured image path
   */
  function bold_entry_feature_image_path() {
    $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
    echo $featured_image[0];
  }

  /**
   * Custom more text for the excerpt more
   */
  function bold_custom_excerpt_more( $more ) {
    return ' ...';
  }
  add_filter( 'excerpt_more', 'bold_custom_excerpt_more' );

  /**
   * Return entry full featured image path
   */
  function bold_category_feature_image() {
    $category_image = '';

    if (function_exists('category_image_src')) {
      $category_image = category_image_src( array( 'size' => 'full' ) , false );
    }

    echo $category_image;
  }

  /**
   * Add CSS class to custom logo
   */
  function bold_custom_logo_class( $html ) {
    $html = str_replace('custom-logo', 'c-logo', $html);

    return $html;
  }
  add_filter( 'get_custom_logo', 'bold_custom_logo_class' );

  /**
   * Remove p tags from archive description
   */
  function bold_custom_archive_description( $description ) {
    $remove = array( '<p>', '</p>' );
    $description = str_replace( $remove, '', $description );
    return $description;
  }
  add_filter( 'get_the_archive_description', 'bold_custom_archive_description' );

  /**
  * Remove parentheses from category list and add span class to posts count
  */
  function bold_categories_postcount_filter( $variable ) {
    $variable = str_replace( '(', '<span class="post-count"> ', $variable );
    $variable = str_replace( ')', ' </span>', $variable );
    return $variable;
  }
  add_filter( 'wp_list_categories', 'bold_categories_postcount_filter' );

  /**
  * Remove parentheses from archive list and add span class to posts count
  */
  function bold_archive_postcount_filter( $variable ) {
    $variable = str_replace( '(', '<span class="post-count"> ', $variable );
    $variable = str_replace( ')', ' </span>', $variable );
    return $variable;
  }
  add_filter( 'get_archives_link', 'bold_archive_postcount_filter' );

  /**
  * Replace class on reply link
  */
  function bold_replace_reply_link_class( $class ) {
    $class = str_replace( "class='comment-reply-link", "class='c-btn outline tiny", $class );
    return $class;
  }
  add_filter( 'comment_reply_link', 'bold_replace_reply_link_class' );

  /**
  * Replace class on cancel reply link
  */
  function bold_replace_cancel_reply_link_class( $cancel_comment_reply_link, $post = null ) {
    $new = str_replace( '<a', '<a class="button outline tiny"', $cancel_comment_reply_link );
    return $new;
  }
  add_filter( 'cancel_comment_reply_link', 'bold_replace_cancel_reply_link_class', 10, 2 );

  /*
   * Change the comment reply link to use 'Reply to &lt;Author First Name>'
   * https://raam.org/2013/personalizing-the-wordpress-comment-reply-link/
   */
  function bold_add_comment_author_to_reply_link( $link, $args, $comment ) {

    $comment = get_comment( $comment );

    // If no comment author is blank, use 'Anonymous'
    if ( empty( $comment->comment_author ) ) {
      if ( !empty( $comment->user_id ) ) {
        $user=get_userdata( $comment->user_id );
        $author=$user->user_login;
      } else {
        $author = esc_html__('Anonymous', 'bold');
      }
    } else {
      $author = $comment->comment_author;
    }

    // If the user provided more than a first name, use only first name
    if( strpos( $author, ' ' ) ) {
      $author = substr( $author, 0, strpos( $author, ' ' ) );
    }

    // Replace Reply Link with "Reply to Author First Name>"
    $reply_link_text = $args['reply_text'];
    $link = str_replace( $reply_link_text, esc_html__( 'Reply to', 'bold' ) . ' ' . $author, $link );

    return $link;
  }
  add_filter( 'comment_reply_link', 'bold_add_comment_author_to_reply_link', 10, 3 );

  /**
   * Add Placehoder in comment Form Field (Comment)
   */
  function bold_comment_textarea_placeholder( $fields ) {
    $fields['comment_field'] = str_replace(
      '<textarea',
      '<textarea placeholder="' . esc_html__( 'Comment', 'bold' ) . '" ',
      $fields['comment_field']
    );

    return $fields;
  }
  add_filter( 'comment_form_defaults', 'bold_comment_textarea_placeholder' );

  /**
   * Custom Comment Form Fields
   * Remove labels and add placeholders instead.
   */
  function bold_custom_comment_form_fields( $fields ) {
    $commenter = wp_get_current_commenter();
    $req = get_option( 'require_name_email' );
    $aria_req = ( $req ? " aria-required='true'" : '' );

    $fields['author'] = '<div class="o-grid"><div class="o-grid__col o-grid__col--4-4-s o-grid__col--1-3-m">'.
      '<p><input id="author" name="author" type="text" placeholder="' . esc_html__( 'Name', 'bold' ) . ( $req ? ' *' : '' ) . '" value="' . esc_attr( $commenter['comment_author'] ) . '" size="20"' . $aria_req . ' /></p></div>';

    $fields['email'] = '<div class="o-grid__col o-grid__col--4-4-s o-grid__col--1-3-m">'.
      '<p><input id="email" name="email" type="text" placeholder="' . esc_html__( 'Email', 'bold' ) . ( $req ? ' *' : '' ) . '" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="20"' . $aria_req . ' /></p></div>';

    $fields['url'] = '<div class="o-grid__col o-grid__col--4-4-s o-grid__col--1-3-m">'.
      '<p><input id="url" name="url" type="text" placeholder="' . esc_html__( 'Website', 'bold' ) . '" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="20"' . $aria_req . ' /></p></div></div>';

    return $fields;
  }
  add_filter( 'comment_form_default_fields', 'bold_custom_comment_form_fields' );

  /**
   * Returns the title escaped, to be used in the share URLs
   */
  function bold_get_escaped_title() {
    echo htmlspecialchars( urlencode( html_entity_decode( get_the_title() . ' - ' ) ) );
  }

  /**
   * Related Posts Function.
   */
  if ( ! function_exists ( 'bold_related_posts' ) ) {
    function bold_related_posts() {
      global $post;
      $tags = wp_get_post_tags( $post->ID );
      $tag_arr = '';

      if( $tags ) {
        foreach( $tags as $tag ) {
          $tag_arr .= $tag->slug . ',';
        }

        $args = array(
          'tag'           => $tag_arr,
          'numberposts'   => 3,
          'post__not_in'  => array( $post->ID )
        );

        $related_posts = get_posts( $args );

        if( $related_posts ) {
          echo '<div class="c-related">';
            echo '<div class="o-grid">';
              echo '<div class="o-grid__col o-grid__col--full">';
                echo '<h5 class="c-related__title">' . esc_html__( 'You Might Be Interested In', 'bold' ) . '</h5>';
              echo '</div>';
              foreach ( $related_posts as $post ) : setup_postdata( $post ); ?>
                <?php get_template_part( 'template-parts/post-card' ); ?>
              <?php endforeach;
            echo '</div>';
          echo '</div>';
        }
      }

      wp_reset_postdata();
    }
  }
}
endif;
add_action( 'after_setup_theme', 'bold_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bold_content_width() {
  $GLOBALS['content_width'] = apply_filters( 'bold_content_width', 640 );
}
add_action( 'after_setup_theme', 'bold_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function bold_widgets_init() {
  register_sidebar( array(
    'name'          => esc_html__( 'Footer First', 'bold' ),
    'id'            => 'footer-first',
    'description'   => esc_html__( 'Add widgets here to appear in site Footer First column.', 'bold' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h2 class="widget__title">',
    'after_title'   => '</h2>',
  ) );

  register_sidebar( array(
    'name'          => esc_html__( 'Footer Second', 'bold' ),
    'id'            => 'footer-second',
    'description'   => esc_html__( 'Add widgets here to appear in site Footer Second column.', 'bold' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h2 class="widget__title">',
    'after_title'   => '</h2>',
  ) );

  register_sidebar( array(
    'name'          => esc_html__( 'Footer Third', 'bold' ),
    'id'            => 'footer-third',
    'description'   => esc_html__( 'Add widgets here to appear in site Footer Third column.', 'bold' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h2 class="widget__title">',
    'after_title'   => '</h2>',
  ) );

  register_sidebar( array(
    'name'          => esc_html__( 'Footer Fourth', 'bold' ),
    'id'            => 'footer-fourth',
    'description'   => esc_html__( 'Add widgets here to appear in site Footer Fourth column.', 'bold' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h2 class="widget__title">',
    'after_title'   => '</h2>',
  ) );
}
add_action( 'widgets_init', 'bold_widgets_init' );

/**
 * Register Fonts
 */
if ( ! function_exists ( 'bold_fonts_url' ) ) {
  function bold_fonts_url() {
    $font_url = '';

    /**
     * Translators: If there are characters in your language that are not supported
     * by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'bold' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Roboto:400,300|Libre Baskerville:400' ), '//fonts.googleapis.com/css' );
    }
    return $font_url;
  }
}

/**
 * Enqueue scripts and styles.
 */
function bold_scripts() {
  global $wp_query;

  wp_enqueue_style( 'bold-fonts', bold_fonts_url(), array(), '1.0.4' );

  if ( ! is_rtl() ) {
    wp_enqueue_style( 'bold-style', get_stylesheet_uri() );
  } else {
    wp_enqueue_style( 'bold-style', get_template_directory_uri() . '/style-rtl.css' );
  }

  wp_enqueue_script( 'bold-main-script', get_template_directory_uri() . '/js/app.min.js', array( 'jquery' ), '1.0.4', true );

  // Max number of pages
  $bold_page_number_max = $wp_query->max_num_pages;

  // Next page to load
	$bold_page_number_next = (get_query_var('paged') > 1) ? get_query_var('paged') + 1 : 2;

  // Get next page link
  $bold_page_link_next = get_pagenum_link(9999999999);

  wp_localize_script( 'bold-main-script', 'bold_config', array(
    'bold_page_number_max'  => $bold_page_number_max,
    'bold_page_number_next' => $bold_page_number_next,
    'bold_page_link_next'   => $bold_page_link_next,
    'bold_load_more'        => esc_html__('Load More', 'bold'),
    'bold_loading'          => esc_html__('Loading', 'bold')
  ) );

  if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
    wp_enqueue_script( 'comment-reply' );
  }
}
add_action( 'wp_enqueue_scripts', 'bold_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Data Importer
 */
require get_template_directory() . '/inc/demo-import.php';
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328947&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        