(function() {
  'use strict';

  // Include Gulp & Tools
  var gulp         = require('gulp'),
      sass         = require('gulp-sass'),
      rtlcss       = require('gulp-rtlcss'),
      autoprefixer = require('gulp-autoprefixer'),
      runSequence  = require('run-sequence'),
      concat       = require('gulp-concat'),
      rename       = require('gulp-rename'),
      jshint       = require('gulp-jshint'),
      uglify       = require('gulp-uglify'),
      plumber      = require('gulp-plumber'),
      gutil        = require('gulp-util');

  var onError = function(err) {
    console.log('An error occurred:', gutil.colors.magenta(err.message));
    gutil.beep();
    this.emit('end');
  };

  // SASS
  gulp.task('sass', function () {
    return gulp.src('./sass/*.scss')
    .pipe(plumber({ errorHandler: onError }))
    .pipe(sass({outputStyle: 'expanded'}))
    .pipe(autoprefixer())
    .pipe(gulp.dest('./'))              // Output LTR stylesheets
    .pipe(rtlcss())                     // Convert to RTL
    .pipe(rename({ suffix: '-rtl' }))   // Rename style.css to 'style-rtl.css'
    .pipe(gulp.dest('./'));             // Output RTL stylesheets
  });

  // JavaScript
  gulp.task('js', function() {
    return gulp.src([
      './node_modules/evil-icons/assets/evil-icons.min.js',
      './node_modules/headroom.js/dist/headroom.js',
      './node_modules/headroom.js/dist/jQuery.headroom.js',
      './bower_components/jquery.fitvids/jquery.fitvids.js',
      './bower_components/jQuery-viewport-checker/dist/jquery.viewportchecker.min.js',
      './js/scripts/skip-link-focus-fix.js',
      './js/scripts/app.js'])
      .pipe(jshint())
      .pipe(jshint.reporter('jshint-stylish'))
      .pipe(plumber({ errorHandler: onError }))
      .pipe(concat('app.js'))
      .pipe(rename({ suffix: '.min' }))
      .pipe(uglify())
      .pipe(gulp.dest('./js'));
  });

  // Watch
  gulp.task('watch', function() {
    gulp.watch('./sass/**/*.scss', ['sass']);
    gulp.watch('./js/scripts/**/*.js', ['js']);
  });

  // Build
  gulp.task('build', [], function() {
    runSequence('sass', 'js');
  });

  // Default
  gulp.task('default', ['build', 'watch']);

})();